/*******************************************************************************
 * Copyright (c) 2009 Pafsanias Ftakas.
 *
 * This file is part of DistProc.
 *
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * DistProc is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * Eclipse Public License v1.0 for more details.
 *
 * Contributors:
 *     Pafsanias Ftakas - initial API and implementation
 *******************************************************************************/
package com.koutra.dist.proc.cluster;

import org.jgroups.util.Streamable;

/**
 * Every runnable that runs on the cluster must implement this interface.
 * 
 * @author Pafsanias Ftakas
 */
public interface IClusterRunnable extends Runnable {
	/**
	 * Accessor for the <code>Streamable</code> instance that will travel down the
	 * wire to the cluster node that is to execute this runnable.
	 * 
	 * @return the object that will travel down the wire to the cluster node that
	 * will execute this instance.
	 */
	Streamable getWirePayload();
	
	/**
	 * This method is called by the cluster node that executes the runnable
	 * to make any code that referred to the local state in the location where
	 * the runnable was created, refer to local state of the cluster node instead.
	 * 
	 * @param container the container that can be queried for state.
	 */
	void setConainingObject(Object container);
}
