/*******************************************************************************
 * Copyright (c) 2009 Pafsanias Ftakas.
 *
 * This file is part of DistProc.
 *
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * DistProc is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * Eclipse Public License v1.0 for more details.
 *
 * Contributors:
 *     Pafsanias Ftakas - initial API and implementation
 *******************************************************************************/
package com.koutra.dist.proc.model;

import java.io.DataInputStream;
import java.io.DataOutputStream;
import java.io.IOException;
import java.util.Collections;
import java.util.List;
import java.util.concurrent.Future;

/**
 * A faucet adapter to make split pipeline items look to pipeline items further
 * down the pipeline like normal pipeline items (this adapter hides away the faucet
 * index that appears in most of the faucet related APIs of the split pipeline items).
 * 
 * @author Pafsanias Ftakas
 */
public class FaucetAdapter implements IPipelineItem, IFaucet {
	protected ISplitPipelineItem split;
	protected int index;
	
	public FaucetAdapter(ISplitPipelineItem split, int index) {
		this.split = split;
		this.index = index;
	}

	@Override
	public void dispose() {
		split.dispose(index);
	}

	@Override
	public String getId() {
		return split.getId();
	}

	@Override
	public ISink getSink() {
		return split.getSink(index);
	}

	@Override
	public Object getSource(ContentType contentType) {
		return split.getSource(index, contentType);
	}

	@Override
	public void hookupSink(ISink sink) {
		split.hookupSink(index, sink);
	}

	@Override
	public boolean supportsOutput(ContentType contentType) {
		return split.supportsOutput(contentType);
	}

	@Override
	public Object consume(ISink previousSink) {
		return split.consume(previousSink);
	}

	@Override
	public void endMux() {
		split.endMux();
	}

	@Override
	public void handleMuxSwitch() {
		split.handleMuxSwitch();
	}

	@Override
	public void consume() {
		split.consume();
	}
	
	@Override
	public Future<?> consumeAsynchronously() {
		return split.consumeAsynchronously();
	}

	@Override
	public String dumpPipeline() {
		return split.dumpPipeline();
	}

	@Override
	public IFaucet getFaucet() {
		return split.getFaucet();
	}

	@Override
	public void hookupFaucet(IFaucet faucet) {
		split.hookupFaucet(faucet);
	}

	@Override
	public void registerSource(Object source) {
		split.registerSource(source);
	}

	@Override
	public boolean supportsInput(ContentType contentType) {
		return split.supportsInput(contentType);
	}

	@Override
	public void readFrom(DataInputStream in) throws IOException,
			IllegalAccessException, InstantiationException {
		split.readFrom(in);
	}

	@Override
	public void writeTo(DataOutputStream out) throws IOException {
		split.writeTo(out);
	}

	@Override
	public List<ISink> getTerminalSinks() {
		if (split.getSink(index) instanceof IFaucet) {
			return ((IFaucet) split.getSink(index)).getTerminalSinks();
		} else if (split.getSink(index) instanceof ISplitPipelineItem) {
			return ((ISplitPipelineItem) split.getSink(index)).getTerminalSinks();
		} else {
			return Collections.singletonList(split.getSink(index));
		}
	}

}
