/*******************************************************************************
 * Copyright (c) 2009 Pafsanias Ftakas.
 *
 * This file is part of DistProc.
 *
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * DistProc is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * Eclipse Public License v1.0 for more details.
 *
 * Contributors:
 *     Pafsanias Ftakas - initial API and implementation
 *******************************************************************************/
package com.koutra.dist.proc.model;

import java.util.List;

/**
 * Implementors of this class represent an input source for the transformation process.
 * 
 * @author Pafsanias Ftakas
 */
public interface IFaucet extends IIdentifiable {
	/**
	 * Answers the question of whether the faucet instance supports the particular
	 * content type. 
	 * @param contentType the content type
	 * @return true iff the faucet instance supports the particular content type
	 */
	boolean supportsOutput(ContentType contentType);
	
	/**
	 * Connects the sink argument to this faucet.
	 * @param sink the sink
	 */
	void hookupSink(ISink sink);
	
	/**
	 * Access the source that this faucet represents. The actual type of the faucet's
	 * source depends on the content type.
	 * @param contentType the content type for which this faucet should return a source.
	 * Throws a <code>XformationException</code> if the content type is not supported by
	 * the faucet. 
	 * @return The (content type related) source that this faucet represents.
	 */
	Object getSource(ContentType contentType);
	
	/**
	 * Accessor to the sink of this faucet.
	 * @return This faucet's sink.
	 */
	ISink getSink();
	
	/**
	 * Dispose any resources held by the faucet.
	 */
	void dispose();
	
	/**
	 * Helper for the execution of processes. It returns the terminal sinks that
	 * this faucet is linked to.
	 * @return A list of the terminal sinks that this faucet is linked with, or the
	 * empty list if there are none.
	 */
	List<ISink> getTerminalSinks();
}
