/*******************************************************************************
 * Copyright (c) 2009 Pafsanias Ftakas.
 *
 * This file is part of DistProc.
 *
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * DistProc is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * Eclipse Public License v1.0 for more details.
 *
 * Contributors:
 *     Pafsanias Ftakas - initial API and implementation
 *******************************************************************************/
package com.koutra.dist.proc.model;

import java.util.concurrent.Future;

/**
 * Implementors of this interface represent a termination of a transformation process.
 * 
 * @author Pafsanias Ftakas
 */
public interface ISink extends IIdentifiable {
	/**
	 * Answers the question of whether the sink instance supports the particular
	 * content type. 
	 * @param contentType the content type
	 * @return true iff the sink instance supports the particular content type
	 */
	boolean supportsInput(ContentType contentType);

	/**
	 * Connects the faucet argument to this sink.
	 * @param faucet the faucet
	 */
	void hookupFaucet(IFaucet faucet);
	
	/**
	 * Returns the faucet hooked up with this sink.
	 * @return the faucet hooked up with this sink.
	 */
	IFaucet getFaucet();
	
	/**
	 * Helper for the mux instances. The source is the input source that the mux instance
	 * should use. It also calls the consume interface up the chain.
	 */
	void registerSource(Object source);
	
	/**
	 * Helper to dump the pipeline from this sink down the chain.
	 * @return a string representin the pipeline down the chain.
	 */
	String dumpPipeline();
	
	/**
	 * Consume the faucet.
	 */
	void consume();
	
	/**
	 * Consume the faucet asynchronously. This will consume the faucet in a separate thread.
	 * @return a <code>Future</code> object to check the status of the computation.
	 */
	Future<?> consumeAsynchronously();
	
	/**
	 * Dispose any resources held by the sink.
	 */
	void dispose();
}
