/*******************************************************************************
 * Copyright (c) 2009 Pafsanias Ftakas.
 *
 * This file is part of DistProc.
 *
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * DistProc is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * Eclipse Public License v1.0 for more details.
 *
 * Contributors:
 *     Pafsanias Ftakas - initial API and implementation
 *******************************************************************************/
package com.koutra.dist.proc.util;

import java.io.IOException;
import java.io.OutputStream;

import org.apache.log4j.Logger;

public class DumpingOutputStream extends OutputStream {
	private static final Logger logger = Logger.getLogger(DumpingOutputStream.class);
	
	private OutputStream delegate;
	
	public DumpingOutputStream(OutputStream delegate) {
		if (logger.isTraceEnabled())
			logger.trace("Created dumping output stream");
		this.delegate = delegate;
	}

	@Override
	public void write(int b) throws IOException {
		delegate.write(b);
		
		if (logger.isTraceEnabled()) {
			byte[] buffer = new byte[1];
			buffer[0] = (byte) b;
			logger.trace("Written: " + ByteArrayUtil.getFullHexDump(buffer, 0, 1));
			logger.trace("Written: " + new String(buffer, 0, 1));
		}
	}
	
	@Override
	public void write(byte[] b, int off, int len) throws IOException {
		delegate.write(b, off, len);
		
		if (logger.isTraceEnabled()) {
			logger.trace("Written: " + ByteArrayUtil.getFullHexDump(b, off, len));
			logger.trace("Written: " + new String(b, off, len));
		}
	}
	
	@Override
	public void close() throws IOException {
		if (logger.isTraceEnabled())
			logger.trace("Closing output stream.");
		delegate.close();
	}

}
